@@ -38,7 +38,7 @@ else:
 def main():
     po = pofile(output_file)
     po = file2msgstr(input_file, po, path, encoding=args.encoding, overwrite=args.overwrite, same=args.same)
-    po.save(output_file, newline=CONFIG.newline)
+    po.save(output_file, newline=CONFIG.newline_po)
 
 
 if __name__ == "__main__":
